import Flutter
import UIKit

public class SwiftAlertControllerPlugin: NSObject, FlutterPlugin,FlutterStreamHandler {
    
   var eventsSink:FlutterEventSink?
    
   public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "alert_controller", binaryMessenger: registrar.messenger())
    let instance = SwiftAlertControllerPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
    
    let eventChannel = FlutterEventChannel(name: "alert_controller_event", binaryMessenger: registrar.messenger())
    eventChannel.setStreamHandler(instance)
   }
    
    public func onListen(withArguments arguments: Any?, eventSink events: @escaping FlutterEventSink) -> FlutterError? {
        self.eventsSink = events
        return nil
    }

    public func onCancel(withArguments arguments: Any?) -> FlutterError? {
        return nil
    }

    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        switch call.method {
            case "show":
                if  let params = call.arguments as? Dictionary<String, Any> {
                    let title = params["title"] as? String
                    let message = params["message"] as? String
                    let preferredStyle = params["preferredStyle"] as! String
                    var alterStyle = (preferredStyle == "actionSheet") ? UIAlertController.Style.actionSheet : UIAlertController.Style.alert
                    if UIDevice.current.userInterfaceIdiom == .pad { //ipad 直接显示alert 否则在ipad上面actionSheet 会崩溃
                        alterStyle = UIAlertController.Style.alert
                    }
                    let alertVc = UIAlertController(title: title, message: message, preferredStyle: alterStyle)
                    if let actions = params["actions"] as? Array<Any> {
                        for item in actions {
                            if let dict = item as? Dictionary<String, Any> {
                              let title = dict["title"] as? String
                              let isEnabled = dict["isEnabled"] as? Bool
                              let preferredStyle = dict["preferredStyle"] as! String
                              var style = UIAlertAction.Style.default
                              if preferredStyle == "cancel" {
                                style = .cancel
                              }else if preferredStyle == "destructive" {
                                style = .destructive
                              }
                              let action = UIAlertAction(title: title, style: style) { (action) in
                                if let events = self.eventsSink {
                                    events(action.title ?? "unkown event")
                                }
                              }
                              action.isEnabled = isEnabled ?? true
                              alertVc.addAction(action)
                            }
                        }
                    }
                    UIApplication.shared.keyWindow!.rootViewController?.present(alertVc, animated: true, completion: nil)
                    result(true)
                }
                break
            default:
                break
        }
  }
}
