import 'package:flutter/services.dart';

///弹框的类型
enum AlertStyle {
  actionSheet,
  alert
}

///action的类型
enum AlertActionStyle {
  normal,
  cancel,
  destructive
}

///每一个action 标题点击的回调
typedef void AlertActionHandle(AlertAction action);

class AlertAction {
  String title;
  AlertActionStyle style;
  bool isEnabled = true;
  AlertActionHandle handler;
  AlertAction({this.title,this.style,this.isEnabled,this.handler});
}

/// 显示一个ios原生的系统弹框
class AlertController {
    static const EventChannel  _eventChannel =  const EventChannel('alert_controller_event');
    static const MethodChannel  _methodChannel = const MethodChannel('alert_controller');
    String title;
    String message;
    AlertStyle preferredStyle;
    AlertController({this.title,this.message,this.preferredStyle});
    List<AlertAction> actions = [];
    /// 添加一个action 标题
    addAction(AlertAction action){
         ///过滤重复的
        for (var item in this.actions) {
          if (item.title == action.title && item.style == action.style) {
            return;
          } 
        }
        this.actions.add(action);
    }

    ///显示弹框
    show(){
      var styleStr = (this.preferredStyle == AlertStyle.actionSheet) ? "actionSheet" : "alert";
      var tempActions = [];
      for (AlertAction item in this.actions) {
          var style = "default";
          if (item.style == AlertActionStyle.cancel) {
            style = "cancel";
          }else if(item.style == AlertActionStyle.destructive) {
            style = "destructive";
          }
          var itemInfo = Map();
          itemInfo ["title"] = item.title;
          itemInfo ["preferredStyle"] = style;
          itemInfo ["isEnabled"] = item.isEnabled;
          tempActions.add(itemInfo);
      }
      var arguments = Map();
      arguments["title"] = this.title;
      arguments["message"] = this.message;
      arguments["preferredStyle"] =  styleStr;
      arguments["actions"] = tempActions;
      _methodChannel.invokeMethod("show",arguments);

      _eventChannel.receiveBroadcastStream().listen((onData){
          for (var item in this.actions) {
            if (item.title == onData) {
              item.handler(item);
              return;
            } 
        }
      });

    }

}
